@@ -63,17 +63,17 @@ public slots:
   void gotoEntryPage(QString pgno);
   void gotoEntryPage(int pgno, int dir=0);
   void gotoTOC(int pgno=-1);
-  void goTOC(Qt::KeyboardModifiers=0);
+  void goTOC(Qt::KeyboardModifiers=Qt::NoModifier);
   void gotoFront();
   void nextPage();
-  void goRelative(int n, Qt::KeyboardModifiers=0);
+  void goRelative(int n, Qt::KeyboardModifiers=Qt::NoModifier);
   void previousPage();
-  void lastPage(Qt::KeyboardModifiers m=0);
-  void newPage(Qt::KeyboardModifiers m=0);
+  void lastPage(Qt::KeyboardModifiers m=Qt::NoModifier);
+  void newPage(Qt::KeyboardModifiers m=Qt::NoModifier);
   void openFindDialog();
   void openGotoPageDialog();
   void htmlDialog();
-  void drop(QDropEvent);
+  // void drop(QDropEvent const &);
   void ensureSearchVisible(QString uuid, QString phrase);
   void openPrintDialog();
 signals:
@@ -85,17 +85,17 @@ public:
   class Notebook *notebook() const;
   void markCursor(QPointF, QFont, QColor);
 protected:
-  virtual void resizeEvent(QResizeEvent *);
-  virtual void keyPressEvent(QKeyEvent *);
-  virtual void keyReleaseEvent(QKeyEvent *);
-  virtual void mousePressEvent(QMouseEvent *);
-  virtual void wheelEvent(QWheelEvent *);
-  virtual void dragEnterEvent(QDragEnterEvent *);
-  virtual void enterEvent(QEvent *);
-  virtual void leaveEvent(QEvent *);
-  virtual void inputMethodEvent(QInputMethodEvent *);
-  virtual void focusInEvent(QFocusEvent *);
-  virtual void focusOutEvent(QFocusEvent *);
+  virtual void resizeEvent(QResizeEvent *) override;
+  virtual void keyPressEvent(QKeyEvent *) override;
+  virtual void keyReleaseEvent(QKeyEvent *) override;
+  virtual void mousePressEvent(QMouseEvent *) override;
+  virtual void wheelEvent(QWheelEvent *) override;
+  virtual void dragEnterEvent(QDragEnterEvent *) override;
+  virtual void enterEvent(QEnterEvent *) override;
+  virtual void leaveEvent(QEvent *) override;
+  virtual void inputMethodEvent(QInputMethodEvent *) override;
+  virtual void focusInEvent(QFocusEvent *) override;
+  virtual void focusOutEvent(QFocusEvent *) override;
   //  void dragMoveEvent(QDragMoveEvent *);
   virtual void drawBackground(QPainter *, QRectF const &);
   virtual void drawForeground(QPainter *, QRectF const &);
